<?php

/**
 * Main class. Load everything from here.
 *
 * @author Projects Engine <contact@projectsengine.com>
 */
class BlocksByProjectsEngine {
    /**
     * @var object
     */
    private $loader;

    /**
     * @var array|false|string
     */
    private $plugin_domain;

    /**
     * @var array|false|string
     */
    private $version;

    /**
     * @since    1.0.0
     * @access   private
     * @var array|false|string
     */
    private $plugin_name;

    /**
     *
     */
    public function __construct() {
        $this->plugin_domain = 'blocks-by-projects-engine';
        $this->version = '2.0.1';
        $this->plugin_name = 'Blocks by Projects Engine';

        $this->load_dependencies();
        $this->define_admin_hooks();
        $this->define_public_hooks();
        $this->define_gutenberg_blocks();
        $this->define_shortcodes();
    }

    /**
     *
     */
    private function load_dependencies() {
        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path( __FILE__ ) . '/loader.php';

        $this->loader = new BBPELoader();
    }

    /**
     * @since 1.0.0
     *
     * Define Gutenberg blocks
     */
    private function define_gutenberg_blocks() {
        require plugin_dir_path( __FILE__ ) . '/gutenberg.php';

        $blocks = new BBPEGutenberg( $this->get_domain(), $this->get_version(), $this->get_name() );

        /**
         * Registers all block assets so that they can be enqueued through the Block Editor in
         * the corresponding context.
         *
         * @link https://wordpress.org/gutenberg/handbook/designers-developers/developers/block-api/block-registration/
         */
        $this->loader->add_action( 'block_categories', $blocks, 'bbpe_block_categories', 10, 2 );
        $this->loader->add_action( 'enqueue_block_assets', $blocks, 'bbpe_enqueue_gutenberg_scripts' );
        // Only for the block editor.
//	    $this->loader->add_action( 'enqueue_block_editor_assets', $blocks, 'enqueue_gutenberg_scripts' );
        $this->loader->add_action( 'init', $blocks, 'bbpe_register_blocks' );
    }

    /**
     * Define the admin hooks and admin pages.
     *
     * @since 1.0.0
     */
    private function define_admin_hooks() {
        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path( __FILE__ ) . '/admin.php';

        $admin = new BBPEAdmin( $this->get_domain(), $this->get_version() );

        $this->loader->add_action( 'init', $admin, 'bbpe_load_text_domain' );
        $this->loader->add_action( 'init', $admin, 'bbpe_add_image_size' );
        $this->loader->add_filter( 'image_size_names_choose', $admin, 'bbpe_custom_sizes' );
    }

    /**
     *
     */
    private function define_public_hooks() {
        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path( __FILE__ ) . '/public.php';

        $public = new BBPEPublic( $this->get_domain(), $this->get_version() );
    }

    /**
     * Define shortcodes in the plugin.
     *
     * @since 1.0.0
     */
    private function define_shortcodes() {
        require_once plugin_dir_path( __FILE__ ) . '/shortcodes.php';

        $shortcode = new BBPEShortcodes( $this->get_domain(), $this->get_version() );
    }

    /**
     * Run the loader to execute all the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run() {
        $this->loader->run();
    }

    /**
     * Get the plugin domain.
     *
     * @since    1.0.0
     */
    private function get_domain() {
        return $this->plugin_domain;
    }

    /**
     * Get the current version of the plugin.
     *
     * @since    1.0.0
     */
    private function get_version() {
        return $this->version;
    }

    /**
     * Get the plugin name.
     *
     * @since    1.0.0
     */
    private function get_name() {
        return $this->plugin_name;
    }
}