const { __ } = wp.i18n;
const { registerPlugin } = wp.plugins;
const { registerBlockType } = wp.blocks;
const { RichText, InspectorControls } = wp.blockEditor;
const { ToggleControl, PanelBody, PanelRow, Panel, CheckboxControl, SelectControl, ColorPicker } = wp.components;

import MetaFieldsInSidebar from './meta-fields';

registerPlugin( 'featured-post-plugin', {
    render() {
        return(<MetaFieldsInSidebar />);
    }
} );

registerBlockType('blocks-by-projects-engine/heading', {
    title: 'Heading - Highlighted',
    category: 'blocks-by-projects-engine',
    icon: 'heading',
    description: 'Highlighted heading with description.',
    keywords: ['heading', 'highlighted'],
    attributes: {
        title: {
            type: 'string',
        },
        content: {
            type: 'string',
            source: 'html',
            selector: 'p'
        },
        heading: {
            type: 'string',
            default: 'h2'
        },
        color: {
            type: 'string',
            default: '#f9f9f9'
        },
    },

    edit: (props) => {
        const { attributes, setAttributes } = props;
        const style = {
            background: attributes.color,
        };
        return (
            <div className="block-heading-highlighted" style={style}>
                <InspectorControls>
                    <PanelBody
                        title="Heading"
                        initialOpen={true}
                    >
                        <Panel>
                            <SelectControl
                                label=""
                                value={attributes.heading}
                                options={[
                                    {label: "H1", value: 'h1'},
                                    {label: "H2", value: 'h2'},
                                    {label: "H3", value: 'h3'},
                                ]}
                                onChange={(newVal) => setAttributes({ heading: newVal })}
                            />
                        </Panel>
                    </PanelBody>

                    <PanelBody
                        title="Background color"
                        initialOpen={true}
                    >
                        <Panel>
                            <ColorPicker
                                color={attributes.color}
                                onChangeComplete={(newVal) => setAttributes({ color: newVal.hex })}
                                disableAlpha
                            />
                        </Panel>
                    </PanelBody>
                </InspectorControls>
                <RichText
                    tagName={attributes.heading}
                    placeholder="Write your heading here"
                    value={attributes.title}
                    onChange={(newText) => setAttributes({ title: newText })}
                />
                <RichText
                    tagName="p"
                    placeholder="Write your paragraph here"
                    value={attributes.content}
                    onChange={(newText) => setAttributes({ content: newText })}
                />
            </div>
        );
    },

    save: (props) => {
        const { attributes } = props;
        const style = {
            background: attributes.color,
        };

        return (
            <div className="block-heading-highlighted" style={style}>
                <RichText.Content
                    tagName={attributes.heading}
                    value={attributes.title}
                />
                <RichText.Content
                    tagName="p"
                    value={attributes.content}
                />
            </div>
        );
    }
});

registerBlockType('blocks-by-projects-engine/table-of-contents', {
    title: 'Table of Contents',
    category: 'blocks-by-projects-engine',
    icon: 'editor-ul',
    description: 'Table of contents.',
    keywords: ['table', 'contents'],
    attributes: {
        title: {
            type: 'string',
            default: 'Table of Contents'
        },
        content: {
            type: 'array',
            source: 'children',
            selector: 'ul',
        },
        heading: {
            type: 'string',
            default: 'h2'
        },
        color: {
            type: 'string',
            default: '#f9f9f9'
        },
    },

    edit: (props) => {
        const { attributes, setAttributes } = props;
        const style = {
            background: attributes.color,
        };
        return (
            <div className="block-table-of-content" style={style}>
                <InspectorControls>
                    <PanelBody
                        title="Heading"
                        initialOpen={true}
                    >
                        <Panel>
                            <SelectControl
                                label=""
                                value={attributes.heading}
                                options={[
                                    {label: "H1", value: 'h1'},
                                    {label: "H2", value: 'h2'},
                                    {label: "H3", value: 'h3'},
                                ]}
                                onChange={(newVal) => setAttributes({ heading: newVal })}
                            />
                        </Panel>
                    </PanelBody>

                    <PanelBody
                        title="Background color"
                        initialOpen={true}
                    >
                        <Panel>
                            <ColorPicker
                                color={attributes.color}
                                onChangeComplete={(newVal) => setAttributes({ color: newVal.hex })}
                                disableAlpha
                            />
                        </Panel>
                    </PanelBody>
                </InspectorControls>
                <RichText
                    tagName={attributes.heading}
                    placeholder="Write your heading here"
                    value={attributes.title}
                    onChange={(newText) => setAttributes({ title: newText })}
                />
                <RichText
                    tagName="ul"
                    multiline="li"
                    placeholder="Write your item here"
                    value={attributes.content}
                    onChange={(newText) => setAttributes({ content: newText })}
                />
            </div>
        );
    },

    save: (props) => {
        const { attributes, className } = props;
        const style = {
            background: attributes.color,
        };

        return (
            <div className="block-table-of-content" style={style}>
                <RichText.Content
                    tagName={attributes.heading}
                    value={attributes.title}
                />
                <RichText.Content
                    tagName="ul"
                    value={attributes.content}
                />
            </div>
        );
    }
});