const { __ } = wp.i18n;
const { compose } = wp.compose;
const { withSelect, withDispatch } = wp.data;

const { PluginDocumentSettingPanel } = wp.editPost;
const { ToggleControl, TextControl, PanelRow } = wp.components;

const MetaFieldsInSidebar = ( { postType, postMeta, setPostMeta } ) => {
    if ( 'post' !== postType ) return null;  // Will only render component for post type 'post'

    return(
        <PluginDocumentSettingPanel title={ __( 'Featured', 'luckies') } icon=" " initialOpen="false">
            <PanelRow>
                <ToggleControl
                    label={ __( 'Make this post featured', 'luckies' ) }
                    onChange={ ( value ) => setPostMeta( { _featured: value } ) }
                    checked={ postMeta._featured }
                />
            </PanelRow>
            <PanelRow>
                <TextControl
                    label={ __( 'Write some notes', 'luckies' ) }
                    value={ postMeta._notes }
                    onChange={ ( value ) => setPostMeta( { _notes: value } ) }
                />
            </PanelRow>
        </PluginDocumentSettingPanel>
    );
}

export default compose( [
    withSelect( ( select ) => {
        return {
            postMeta: select( 'core/editor' ).getEditedPostAttribute( 'meta' ),
            postType: select( 'core/editor' ).getCurrentPostType(),
        };
    } ),
    withDispatch( ( dispatch ) => {
        return {
            setPostMeta( newMeta ) {
                dispatch( 'core/editor' ).editPost( { meta: newMeta } );
            }
        };
    } )
] )( MetaFieldsInSidebar );